@@ -22,6 +22,6 @@ class CriarBoleto(Base):
         if sucesso:
             criar_boleto.update_return(response[0], body)
         else:
-            return response['_dados']['_falha'][0]
+            return response[0]['_dados']['_falha']
 
         return response
